@@ -80,7 +80,7 @@ void ISSnoopDevice(XMLEle *root)
 
 IEQPro::IEQPro()
 {
-    setVersion(1, 8);
+    setVersion(1, 9);
 
     driver.reset(new Base());
 
@@ -188,8 +188,8 @@ bool IEQPro::initProperties()
 
     driver->setDeviceName(getDeviceName());
 
-    // Only CEM40 has 115200 baud, rest are 9600
-    if (strstr(getDeviceName(), "CEM40"))
+    // Only CEM40 and GEM45 have 115200 baud, rest are 9600
+    if (strstr(getDeviceName(), "CEM40") || strstr(getDeviceName(), "GEM45"))
         serialConnection->setDefaultBaudRate(Connection::Serial::B_115200);
 
     double longitude = 0, latitude = 90;
