@@ -34,6 +34,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110 - 1301  USA
 #include <termios.h>
 #endif
 
+#ifdef __FreeBSD__
+#include <string.h>
+#endif
+
 /* Add mutex */
 
 #include <mutex>
